You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by cl...@apache.org on 2016/07/28 19:18:19 UTC

[1/2] activemq-artemis git commit: This closes #678

Repository: activemq-artemis
Updated Branches:
  refs/heads/master 85878513a -> e288272ce


This closes #678


Project: http://git-wip-us.apache.org/repos/asf/activemq-artemis/repo
Commit: http://git-wip-us.apache.org/repos/asf/activemq-artemis/commit/e288272c
Tree: http://git-wip-us.apache.org/repos/asf/activemq-artemis/tree/e288272c
Diff: http://git-wip-us.apache.org/repos/asf/activemq-artemis/diff/e288272c

Branch: refs/heads/master
Commit: e288272ceac595d4fe66ca0195184f74de80fd0b
Parents: 8587851 4f95c8a
Author: Clebert Suconic <cl...@apache.org>
Authored: Thu Jul 28 15:18:11 2016 -0400
Committer: Clebert Suconic <cl...@apache.org>
Committed: Thu Jul 28 15:18:11 2016 -0400

----------------------------------------------------------------------
 .../artemis/api/core/management/AddressControl.java | 16 +++++++++-------
 .../artemis/api/jms/management/JMSQueueControl.java |  6 +++---
 .../artemis/api/jms/management/TopicControl.java    |  4 ++--
 3 files changed, 14 insertions(+), 12 deletions(-)
----------------------------------------------------------------------



[2/2] activemq-artemis git commit: ARTEMIS-405 more bits of JMX doc

Posted by cl...@apache.org.
ARTEMIS-405 more bits of JMX doc


Project: http://git-wip-us.apache.org/repos/asf/activemq-artemis/repo
Commit: http://git-wip-us.apache.org/repos/asf/activemq-artemis/commit/4f95c8a6
Tree: http://git-wip-us.apache.org/repos/asf/activemq-artemis/tree/4f95c8a6
Diff: http://git-wip-us.apache.org/repos/asf/activemq-artemis/diff/4f95c8a6

Branch: refs/heads/master
Commit: 4f95c8a64afd45a17279fb1d16445881bd13f5b0
Parents: 8587851
Author: jbertram <jb...@apache.org>
Authored: Thu Jul 28 09:18:13 2016 -0500
Committer: Clebert Suconic <cl...@apache.org>
Committed: Thu Jul 28 15:18:11 2016 -0400

----------------------------------------------------------------------
 .../artemis/api/core/management/AddressControl.java | 16 +++++++++-------
 .../artemis/api/jms/management/JMSQueueControl.java |  6 +++---
 .../artemis/api/jms/management/TopicControl.java    |  4 ++--
 3 files changed, 14 insertions(+), 12 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/4f95c8a6/artemis-core-client/src/main/java/org/apache/activemq/artemis/api/core/management/AddressControl.java
----------------------------------------------------------------------
diff --git a/artemis-core-client/src/main/java/org/apache/activemq/artemis/api/core/management/AddressControl.java b/artemis-core-client/src/main/java/org/apache/activemq/artemis/api/core/management/AddressControl.java
index 6ec9541..fbecf25 100644
--- a/artemis-core-client/src/main/java/org/apache/activemq/artemis/api/core/management/AddressControl.java
+++ b/artemis-core-client/src/main/java/org/apache/activemq/artemis/api/core/management/AddressControl.java
@@ -16,8 +16,6 @@
  */
 package org.apache.activemq.artemis.api.core.management;
 
-import javax.management.MBeanOperationInfo;
-
 /**
  * An AddressControl is used to manage an address.
  */
@@ -44,18 +42,22 @@ public interface AddressControl {
    @Attribute(desc = "roles  (name and permissions) associated with this address using JSON serialization")
    String getRolesAsJSON() throws Exception;
 
-   @Operation(desc = "returns the number of estimated bytes being used by the queue, used to control paging and blocking",
-      impact = MBeanOperationInfo.INFO)
+   /**
+    * Returns the number of estimated bytes being used by the queue(s), used to control paging and blocking.
+    */
+   @Attribute(desc = "the number of estimated bytes being used by the queue(s), used to control paging and blocking")
    long getAddressSize() throws Exception;
 
-   @Operation(desc = "Returns the sum of messages on queues, including messages in delivery",
-      impact = MBeanOperationInfo.INFO)
+   /**
+    * Returns the sum of messages on queue(s), including messages in delivery.
+    */
+   @Attribute(desc = "the sum of messages on queue(s), including messages in delivery")
    long getNumberOfMessages() throws Exception;
 
    /**
     * Returns the names of the queues bound to this address.
     */
-   @Attribute(desc = "names of the queues bound to this address")
+   @Attribute(desc = "names of the queue(s) bound to this address")
    String[] getQueueNames() throws Exception;
 
    /**

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/4f95c8a6/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java
index 3001ec5..6b9aedc 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/JMSQueueControl.java
@@ -94,9 +94,9 @@ public interface JMSQueueControl extends DestinationControl {
    // Operations ----------------------------------------------------
 
    /**
-    * Returns the Registry bindings associated  to this connection factory.
+    * Returns the Registry bindings associated with this queue.
     */
-   @Operation(desc = "Returns the list of Registry bindings associated")
+   @Attribute(desc = "Returns the list of Registry bindings associated with this queue")
    String[] getRegistryBindings();
 
    /**
@@ -373,7 +373,7 @@ public interface JMSQueueControl extends DestinationControl {
    /**
     * Returns whether the queue is paused.
     */
-   @Operation(desc = "Returns true if the queue is paused.", impact = MBeanOperationInfo.INFO)
+   @Attribute(desc = "Returns true if the queue is paused.")
    boolean isPaused() throws Exception;
 
    /**

http://git-wip-us.apache.org/repos/asf/activemq-artemis/blob/4f95c8a6/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java
----------------------------------------------------------------------
diff --git a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java
index f7be4b2..d94e310 100644
--- a/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java
+++ b/artemis-jms-client/src/main/java/org/apache/activemq/artemis/api/jms/management/TopicControl.java
@@ -60,9 +60,9 @@ public interface TopicControl extends DestinationControl {
    int getNonDurableMessageCount();
 
    /**
     * Returns the Registry bindings associated  to this connection factory.
     */
-   @Operation(desc = "Returns the list of Registry bindings associated")
+   @Attribute(desc = "the list of Registry bindings associated with this topic")
    String[] getRegistryBindings();
 
    /**
@@ -60,9 +60,9 @@ public interface TopicControl extends DestinationControl {
 
    /**
-    * Returns the Registry bindings associated  to this connection factory.
+    * Returns the Registry bindings associated with this topic.
     */